About Plone
===========

Plone is a mature, secure and user-friendly Content Management System (CMS).

Plone - and the Open Source community behind it - aggregates more than 15 years experience in content management.
It offers all major features expected by a modern CMS out-of-the-box.

Lots of customizations can be made trough-the-web, such as creating content types, themes, workflows and much more.
Pushed one step further Plone can be used as a framework on which to build custom CMS-like solutions.

Plone works as a

- full-featured classical server-side rendered CMS,
- headless CMS offering all features as a REST API.


Installing Plone
-----------------

Plone is available on Microsoft Windows, Linux, OSX and BSD platforms.

Plone runs as container in the cloud with Docker.

`Install Plone by choosing an option from plone.org <https://plone.org/download>`_


Documentation
-------------

Consult `the official Plone documentation <https://docs.plone.org>`_ with information for different audiences.

For trainings `comprehensive Plone training material <https://training.plone.org>`_ is available.


What is Plone?
--------------

Plone is a ready-to-run content management system, offering a complete set of features needed by a wide variety of organizations.

Security is built into Plone's architecture from the ground up.
Plone offers fine grained permission control over content and actions.

Plone is easy to set up, extremely flexible,
and provides you with a system for managing web content that is ideal for project groups, communities, web sites, extranets and intranets.

- *Plone is easy to install.*
  Several installation options are available for either your local machine or on servers in the cloud.

- *Plone is easy to use.*
  The Plone Team includes usability experts who have made Plone easy and attractive for content managers to add, update, and maintain content.

- *Plone is international.*
  The Plone interface has more than 35 translations, and tools exist for managing multilingual content.

- *Plone is standard.*
  Plone carefully follows standards for usability and accessibility.
  Plone pages are compliant with US Section 508, and the W3C's AAA rating for accessibility.

- *Plone is Open Source.*
  Plone is licensed under the GNU General Public License, the same license used by Linux.
  This gives you the right to use Plone without a license fee, and to improve upon the product.

- *Plone is supported.*
  There are over three hundred developers in the Plone Development Team around the world, and a multitude of companies that specialize in Plone development and support.

- *Plone is extensible.*
  There is a multitude of add-on products for Plone to add new features and content types.
  In addition, Plone can be scripted using web standard solutions and Open Source languages.

- *Plone is technology neutral.*
  Plone can interoperate with most relational database systems, open source and commercial, and runs on a vast array of
  platforms, including Linux, Windows, Mac OS X, Solaris and BSD.


Technical overview
------------------

Plone is a content management platform written in Python.
It builds upon Zope, an Open Source web application server and development system and thus on the pluggable Zope Component Architecture (ZCA).

Python is the easy-to-learn, widely-used and supported Open Source programming language.
Python can be used to add new features to Plone, and used to understand or make changes to the way that Plone works.

Plone stores its contents in Zope's built-in transactional hierachical object database, the ZODB.
The ZODB can be connected to simple file-storages, scalable ZEO-Servers or Postgres, MySQL and Oracle.
There are addon and techniques, however, to share information with other sources, such as relational databases, LDAP, filesystem
files, etc.


Official Resources
------------------
* `plone.com <https://plone.com/>`_ - Official website for decision makers and evaluators.
* `plone.org <https://plone.org/>`_ - Official website for developers and community.
* `Plone support <https://plone.org/support>`_ - Where to find help.
* `community.plone.org <https://community.plone.org/>`_ - Official community forum, the best place to get help.
* `docs.plone.org <https://docs.plone.org/>`_ - Official documentation for developers/integrators.
* `training.plone.org <https://training.plone.org/>`_ - Training classes for developers/integrators/users/designers.
* `plone.api <https://docs.plone.org/develop/plone.api/docs/index.html>`_ - Documentation for plone.api.
* `plone.restapi <https://plonerestapi.readthedocs.io/en/latest/>`_ - Documentation for plone.restapi.
* `official Gitter chat <https://gitter.im/plone/public>`_ - monitored.

